# pyfax: a Python library for generating teletext tti files.

pyfax is a Python library that can be used to generate teletext tti files.
These files are used by [vbit2](https://github.com/peterkvt80/vbit2) to
generate teletext feeds.

## Documentation 
[![Documentation status](https://readthedocs.org/projects/pyfax/badge/?version=latest)](https://pyfax.readthedocs.io/en/latest/?badge=latest)

Documentation of pyfax can be found on [Read the Docs](https://pyfax.readthedocs.io/en/latest/).

## Installation
[![PyPI](https://img.shields.io/pypi/v/pyfax?color=blue&label=PyPI&logo=pypi&logoColor=white)](https://pypi.org/project/pyfax/)

The latest release of pyfax can be installed by running:

```bash
pip3 install pyfax
```

Alternatively, it can be installed by cloning this repo then running:

```bash
pip3 install .
```

## Testing & coverage
[![🕶️](https://github.com/mscroggs/pyfax/actions/workflows/style-checks.yml/badge.svg)](https://github.com/mscroggs/pyfax/actions/workflows/style-checks.yml)
[![🧪](https://github.com/mscroggs/pyfax/actions/workflows/run-tests.yml/badge.svg)](https://github.com/mscroggs/pyfax/actions/workflows/run-tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/mscroggs/pyfax/badge.svg?branch=main)](https://coveralls.io/github/mscroggs/pyfax?branch=main)
